@@ -10,7 +10,7 @@ use re '/aa';
 use Carp;
 use Errno;
 
-our $VERSION = '1.00_04';
+our $VERSION = '1.00_05';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(BACKUP_NONE
                  BACKUP_SINGLE
@@ -168,8 +168,8 @@ sub backup_copy_internal {
 BEGIN {
     if (eval { symlink("",""); 1 }) {
 	*{rename_backup} = \&rename_backup_posix;
-    } elsif ($^O eq 'MSWin32' && eval { require Win32::FileOp }) {
-	Win32::FileOp->import(qw(MoveFile));
+    } elsif ($^O eq 'MSWin32' && eval { require Win32API::File }) {
+	Win32API::File->import(qw(MoveFile));
 	*{rename_backup} = \&rename_backup_win32;
     } else {
 	warn "using last resort rename method susceptible to a race condition";
@@ -217,7 +217,7 @@ sub rename_backup_win32 {
 	last if MoveFile($tempfilename, $backup_name);
 	unless ($!{EEXIST}) {
 	    return _backup_copy_error($error,
-			  "can't rename $tempfilename to $backup_name: $!");
+			  "can't rename $tempfilename to $backup_name: $^E");
 	}
 	++$num;
     }
